#!/usr/bin/env python
"""
spr2img.py

Convert Acorn Spritefiles into other formats using the Python Imaging Library.
Spritefiles containing multiple images are split into many files which can be
stored in a named directory.

(C) David Boddie 2003-2005

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
MA  02110-1301, USA.
"""

import cmdsyntax, Image, os, spritefile, sys


def list_sprites(sf, spr):

    # Print information on the sprites.
    print
    print 'Spritefile "%s" contains:' % sf
    print
    
    if len(spr.sprites) > 0:
    
        for name in spr.sprites.keys():
        
            print name
        
        print
    
    return


def convert_sprites(spr, output_dir, format):

    # Convert each sprite to the format which uses the suffix given.
    for name, sprite in spr.sprites.items():
    
        # Create an Image object.
        image = Image.fromstring(
            sprite['mode'], (sprite['width'], sprite['height']),
            sprite['image']
            )
        
        # Write the image to a file in the output directory.
        try:
        
            path = os.path.join(output_dir, name) + suffix_sep + format
            fp = open(path, "wb")
            
            image.save(fp, format)
            fp.close()
        
        except IOError:
        
            print "Failed to open file for sprite: %s" % path
        
        except KeyError:
        
            print "Could not convert sprite to format: %s" % format
            break
    
    return



if __name__ == "__main__":

    syntax = "(--list <spritefile>) | " + \
        "([<format>] <spritefile> <output directory>)"
    
    so = cmdsyntax.Syntax(syntax)
    
    matches = so.get_args(sys.argv[1:])
    
    if matches == [] or len(matches) > 1:
    
        toolkit = cmdsyntax.use_GUI()
        
        form = cmdsyntax.Form("Convert sprites", so)
        
        matches = form.get_args()
    
    if len(matches) == 1:
    
        match = matches[0]
    
    else:
    
        match = None
    
    if match is None:
    
        print "Usage: %s %s" % (sys.argv[0], syntax)
        print
        print "List the sprites contained in a Spritefile or extract them"
        print "to a directory, converting them to another format in the"
        print "process."
        print
        print "The output format is determined by the string specified; the"
        print 'default format is "png" (PNG format).'
        print
        sys.exit()
    
    # Determine whether the sprites will be listed or converted.
    listing = match.has_key("list")
    
    # Read the input file name.
    sf = match.get("spritefile")
    
    if not listing:
    
        # Check for a suffix to use.
        format = match.get("format", "png")
        
        # Define a suffix separator.
        if sys.platform == "RISCOS":
        
            suffix_sep = "/"
        
        else:
        
            suffix_sep = "."
        
        # Read the output directory specified, if present.
        output_dir = match.get("output directory", None)
        
        # Try to create the directory.
        if os.path.exists(output_dir):
        
            if not os.path.isdir(output_dir):
            
                print "Could not create directory; a file already " + \
                    "exists: %s" % output_dir
                sys.exit()
        
        else:
        
            # Create a directory.
            try:
            
                os.mkdir(output_dir)
            
            except OSError:
            
                print "Could not create directory: %s" % output_dir
                sys.exit()
    
    # Open the spritefile.
    try:
    
        spr = spritefile.spritefile(open(sf, "rb"))
    
    except IOError:
    
        print "File could not be read: %s" % sf
        sys.exit()
    
    if listing:
    
        # List the sprites.
        list_sprites(sf, spr)
    
    else:
    
        # Convert the sprites.
        convert_sprites(spr, output_dir, format)
    
    # Exit
    sys.exit()
